Django Frontend Template documentation — django-frontend-template 1.2.0 documentation

### Navigation

- index
- next |
- django-frontend-template 1.2.0 documentation »

# Django Frontend Template documentation

Django Frontend Template is a very basic Django template built on HTML5 Boilerplate.

With the convenience of a light-weight installable Django application, create custom templates built on top of one of the most well-known, widespread templates (HTML5 Boilerplate.)

There are no static files included. If you want a heavier-weight application built on HTML5 Boilerplate and Twitter Bootstrap then checkout django-frontend-skeleton. If you want to include often used static files without any templates then check out django-frontend-static.

## Inactive

Django Frontend Template is now inactive. Please use django-frontend.

While continuing to use Django Frontend Template, be sure to force upgrade to avoid namespacing problems.

Read this article for more information.

## Starring

- HTML5 Boilerplate (based on 4.2.0)

## Contents

- Getting Started
  - Install
  - Extend
- Template tags
  - djfrontend
- Template blocks
  - html
  - meta
  - head_css
  - head_js
  - body_id
  - body_class
  - body_content
  - body_js
- License
  - Component Specific Licenses
- Changelog
  - 1.2.0
  - 1.1.0
  - 1.0.0
  - 0.1.0
- Road Map

### Navigation

- index
- next |
- django-frontend-template 1.2.0 documentation »